@@ -6,7 +6,7 @@ import logging
 import moe
 import moe.cli
 from moe.plugins import sync as moe_sync
-from moe.query import QueryError, query
+from moe.util.cli import cli_query, query_parser
 
 log = logging.getLogger("moe.cli.sync")
 
@@ -20,7 +20,7 @@ def add_command(cmd_parsers: argparse._SubParsersAction):
         "sync",
         description="Sync music metadata.",
         help="sync music metadata",
-        parents=[moe.cli.query_parser],
+        parents=[query_parser],
     )
     add_parser.set_defaults(func=_parse_args)
 
@@ -34,15 +34,7 @@ def _parse_args(args: argparse.Namespace):
     Raises:
         SystemExit: Invalid query given or query returned no items.
     """
-    try:
-        items = query(args.query, query_type=args.query_type)
-    except QueryError as err:
-        log.error(err)
-        raise SystemExit(1) from err
-
-    if not items:
-        log.error("No items found to sync.")
-        raise SystemExit(1)
+    items = cli_query(args.query, query_type=args.query_type)
 
     for item in items:
         moe_sync.sync_item(item)
